==> php-codecoverage_12.4.0+dfsg.orig.tar.xz: php-codecoverage-12.4.0/src/Report/Xml/Unit.php <==
<?php declare(strict_types=1);
/*
 * This file is part of phpunit/php-code-coverage.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace SebastianBergmann\CodeCoverage\Report\Xml;

use function assert;
use DOMElement;

/**
 * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
 */
final readonly class Unit
{
    private DOMElement $contextNode;

    public function __construct(DOMElement $context, string $name)
    {
        $this->contextNode = $context;

        $this->setName($name);
    }

    public function setLines(int $start, int $executable, int $executed): void
    {
        $this->contextNode->setAttribute('start', (string) $start);
        $this->contextNode->setAttribute('executable', (string) $executable);
        $this->contextNode->setAttribute('executed', (string) $executed);
    }

    public function setCrap(float $crap): void
    {
        $this->contextNode->setAttribute('crap', (string) $crap);
    }

    public function setNamespace(string $namespace): void
    {
        $node = $this->contextNode->getElementsByTagNameNS(
            'https://schema.phpunit.de/coverage/1.0',
            'namespace',
        )->item(0);

        if ($node === null) {
            $node = $this->contextNode->appendChild(
                $this->contextNode->ownerDocument->createElementNS(
                    'https://schema.phpunit.de/coverage/1.0',
                    'namespace',
                ),
            );
        }

        assert($node instanceof DOMElement);

        $node->setAttribute('name', $namespace);
    }

    public function addMethod(string $name): Method
    {
        $node = $this->contextNode->appendChild(
            $this->contextNode->ownerDocument->createElementNS(
                'https://schema.phpunit.de/coverage/1.0',
                'method',
            ),
        );

        assert($node instanceof DOMElement);

        return new Method($node, $name);
    }

    private function setName(string $name): void
    {
        $this->contextNode->setAttribute('name', $name);
    }
}

==> php-codecoverage_12.5.0+dfsg.orig.tar.xz: php-codecoverage-12.5.0/src/Report/Xml/Unit.php <==
<?php declare(strict_types=1);
/*
 * This file is part of phpunit/php-code-coverage.
 *
 * (c) Sebastian Bergmann <sebastian@phpunit.de>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace SebastianBergmann\CodeCoverage\Report\Xml;

use function assert;
use DOMElement;

/**
 * @internal This class is not covered by the backward compatibility promise for phpunit/php-code-coverage
 */
final readonly class Unit
{
    private DOMElement $contextNode;

    public function __construct(
        DOMElement $context,
        string $name,
        string $namespace,
        int $start,
        int $executable,
        int $executed,
        float $crap
    ) {
        $this->contextNode = $context;

        $this->contextNode->setAttribute('name', $name);
        $this->contextNode->setAttribute('start', (string) $start);
        $this->contextNode->setAttribute('executable', (string) $executable);
        $this->contextNode->setAttribute('executed', (string) $executed);
        $this->contextNode->setAttribute('crap', (string) $crap);

        $node = $this->contextNode->appendChild(
            $this->contextNode->ownerDocument->createElementNS(
                Facade::XML_NAMESPACE,
                'namespace',
            ),
        );
        assert($node instanceof DOMElement);

        $node->setAttribute('name', $namespace);
    }

    public function addMethod(
        string $name,
        string $signature,
        string $start,
        ?string $end,
        string $executable,
        string $executed,
        string $coverage,
        string $crap
    ): void {
        $node = $this->contextNode->appendChild(
            $this->contextNode->ownerDocument->createElementNS(
                Facade::XML_NAMESPACE,
                'method',
            ),
        );

        assert($node instanceof DOMElement);

        new Method(
            $node,
            $name,
            $signature,
            $start,
            $end,
            $executable,
            $executed,
            $coverage,
            $crap,
        );
    }
}
